@@ -60,11 +60,10 @@ impl SqliteDataProvide {
     }
 }
 
-#[async_trait]
 impl DataProvider for SqliteDataProvide {
     async fn load_all_entries(&self) -> anyhow::Result<Vec<Entry>> {
         let entries: Vec<EntryIntermediate> = sqlx::query_as(
-            r"SELECT entries.id, entries.title, entries.date, entries.content, GROUP_CONCAT(tags.tag) AS tags
+            r"SELECT entries.id, entries.title, entries.date, entries.content, entries.priority, GROUP_CONCAT(tags.tag) AS tags
             FROM entries
             LEFT JOIN tags ON entries.id = tags.entry_id
             GROUP BY entries.id
@@ -84,13 +83,14 @@ impl DataProvider for SqliteDataProvide {
 
     async fn add_entry(&self, entry: EntryDraft) -> Result<Entry, ModifyEntryError> {
         let row = sqlx::query(
-            r"INSERT INTO entries (title, date, content)
-            VALUES($1, $2, $3)
+            r"INSERT INTO entries (title, date, content, priority)
+            VALUES($1, $2, $3, $4)
             RETURNING id",
         )
         .bind(&entry.title)
         .bind(entry.date)
         .bind(&entry.content)
+        .bind(entry.priority)
         .fetch_one(&self.pool)
         .await
         .map_err(|err| {
@@ -136,12 +136,14 @@ impl DataProvider for SqliteDataProvide {
             r"UPDATE entries
             Set title = $1,
                 date = $2,
-                content = $3
-            WHERE id = $4",
+                content = $3,
+                priority = $4
+            WHERE id = $5",
         )
         .bind(&entry.title)
         .bind(entry.date)
         .bind(&entry.content)
+        .bind(entry.priority)
         .bind(entry.id)
         .execute(&self.pool)
         .await
@@ -202,7 +204,7 @@ impl DataProvider for SqliteDataProvide {
             .join(", ");
 
         let sql = format!(
-            r"SELECT entries.id, entries.title, entries.date, entries.content, GROUP_CONCAT(tags.tag) AS tags
+            r"SELECT entries.id, entries.title, entries.date, entries.content, entries.priority, GROUP_CONCAT(tags.tag) AS tags
             FROM entries
             LEFT JOIN tags ON entries.id = tags.entry_id
             WHERE entries.id IN ({})
@@ -228,15 +230,22 @@ impl DataProvider for SqliteDataProvide {
         Ok(EntriesDTO::new(entry_drafts))
     }
 
-    async fn import_entries(&self, entries_dto: EntriesDTO) -> anyhow::Result<()> {
-        debug_assert_eq!(
-            TRANSFER_DATA_VERSION, entries_dto.version,
-            "Version mismatches check if there is a need to do a converting to the data"
+    async fn assign_priority_to_entries(&self, priority: u32) -> anyhow::Result<()> {
+        let sql = format!(
+            r"UPDATE entries
+            SET priority = '{}'
+            WHERE priority IS NULL;",
+            priority
         );
 
-        for entry_darft in entries_dto.entries {
-            self.add_entry(entry_darft).await?;
-        }
+        sqlx::query(sql.as_str())
+            .execute(&self.pool)
+            .await
+            .map_err(|err| {
+                log::error!("Assign priority to entries failed. Error info {err}");
+
+                anyhow!(err)
+            })?;
 
         Ok(())
     }
