@@ -16,10 +16,10 @@ mod settings;
 
 #[tokio::main]
 async fn main() -> Result<()> {
-    let mut settings = Settings::new().await?;
-
     let cli = cli::Cli::parse();
 
+    let mut settings = Settings::new(cli.config_path.clone()).await?;
+
     let mut pending_cmd = None;
 
     match cli.handle_cli(&mut settings).await? {
